@@ -1,18 +1,18 @@
 # -*- coding: utf-8 -*-
 
+import asyncio
 import weakref
 from functools import partial
+from random import randint
+from typing import List, Union, Tuple
 
-import asyncio
 from aiokafka import AIOKafkaConsumer, ConsumerRebalanceListener, ConsumerRecord
 from humanize import naturalsize
 from kafka import TopicPartition
-from pydantic import validator, root_validator
-from random import randint
-from typing import List, Union, Optional, Tuple
-
 from patchwork.core import AsyncSubscriber, Task
 from patchwork.core.utils import AsyncQueue
+from pydantic import root_validator
+
 from .common import SECOND, get_node_id, MINUTE
 
 # how much multiply some periods to get timeout value
